==> python-amazon-sp-api-1.3.5.tar.gz: python-amazon-sp-api-1.3.5/sp_api/api/__init__.py <==
from .finances.finances import Finances
from .notifications.notifications import Notifications
from .orders.orders import Orders
from .product_fees.product_fees import ProductFees
from .sellers.sellers import Sellers
from .reports.reports import Reports
from .reports.reports import Reports as ReportsV2

from .products.products import Products
from .sales.sales import Sales
from .catalog.catalog import Catalog
from .feeds.feeds import Feeds
from .feeds.feeds import Feeds as FeedsV2

from .inventories.inventories import Inventories
from .fulfillment_inbound.fulfillment_inbound import FulfillmentInbound
from .upload.upload import Upload
from .messaging.messaging import Messaging
from .merchant_fulfillment.merchant_fulfillment import MerchantFulfillment

##### DO NOT DELETE ########## INSERT IMPORT HERE #######
from .listings_restrictions.listings_restrictions import ListingsRestrictions



from .messaging.messaging import Messaging

from .catalog_items.catalog_items import CatalogItems, CatalogItemsVersion

from .product_type_definitions.product_type_definitions import ProductTypeDefinitions

from .listings_items.listings_items import ListingsItems

from .vendor_transaction_status.vendor_transaction_status import VendorTransactionStatus

from .vendor_shipments.vendor_shipments import VendorShipments

from .vendor_orders.vendor_orders import VendorOrders

from .vendor_invoices.vendor_invoices import VendorInvoices

from .vendor_direct_fulfillment_transactions.vendor_direct_fulfillment_transactions import VendorDirectFulfillmentTransactions

from .vendor_direct_fulfillment_shipping.vendor_direct_fulfillment_shipping import VendorDirectFulfillmentShipping

from .vendor_direct_fulfillment_payments.vendor_direct_fulfillment_payments import VendorDirectFulfillmentPayments

from .vendor_direct_fulfillment_orders.vendor_direct_fulfillment_orders import VendorDirectFulfillmentOrders

from .vendor_direct_fulfillment_inventory.vendor_direct_fulfillment_inventory import VendorDirectFulfillmentInventory

from .tokens.tokens import Tokens

from .solicitations.solicitations import Solicitations

from .shipping.shipping import Shipping

from .services.services import Services

from .fba_small_and_light.fba_small_and_light import FbaSmallAndLight

from .fba_inbound_eligibility.fba_inbound_eligibility import FbaInboundEligibility

from .authorization.authorization import Authorization

from .aplus_content.aplus_content import AplusContent

from .fulfillment_outbound.fulfillment_outbound import FulfillmentOutbound

from .replenishment.replenishment import Replenishment

from .supply_sources.supply_sources import SupplySources

from .data_kiosk.data_kiosk import DataKiosk


__all__ = [
    "Sales",
    "Products",
    "Reports",
    "Orders",
    "Sellers",
    "Notifications",
    "ProductFees",
    "Finances",
    "Catalog",
    "Feeds",
    "Inventories",
    "FulfillmentInbound",
    'Upload',
    "Messaging",
    "FulfillmentInbound",
    "MerchantFulfillment",
    ##### DO NOT DELETE ########## INSERT TITLE HERE #######
    "ListingsRestrictions",
    "CatalogItemsVersion",
    "Feeds",
    "FeedsV2",
    "ReportsV2",

    "Messaging",

    "CatalogItems",

    "ProductTypeDefinitions",

    "ListingsItems",

    "VendorTransactionStatus",

    "VendorShipments",

    "VendorOrders",

    "VendorInvoices",

    "VendorDirectFulfillmentTransactions",

    "VendorDirectFulfillmentShipping",

    "VendorDirectFulfillmentPayments",

    "VendorDirectFulfillmentOrders",

    "VendorDirectFulfillmentInventory",

    "Tokens",

    "Solicitations",

    "Shipping",

    "Services",

    "FbaSmallAndLight",

    "FbaInboundEligibility",

    "Authorization",

    "AplusContent",

    "FulfillmentOutbound",
    
    "Replenishment",

    "SupplySources",

    "DataKiosk"

]

==> python-amazon-sp-api-1.5.2.tar.gz: python-amazon-sp-api-1.5.2/sp_api/api/__init__.py <==
from .finances.finances import Finances
from .notifications.notifications import Notifications
from .orders.orders import Orders
from .product_fees.product_fees import ProductFees
from .sellers.sellers import Sellers
from .reports.reports import Reports
from .reports.reports import Reports as ReportsV2

from .products.products import Products
from .sales.sales import Sales
from .catalog.catalog import Catalog
from .feeds.feeds import Feeds
from .feeds.feeds import Feeds as FeedsV2

from .inventories.inventories import Inventories
from .fulfillment_inbound.fulfillment_inbound import FulfillmentInbound
from .upload.upload import Upload
from .messaging.messaging import Messaging
from .merchant_fulfillment.merchant_fulfillment import MerchantFulfillment

##### DO NOT DELETE ########## INSERT IMPORT HERE #######
from .listings_restrictions.listings_restrictions import ListingsRestrictions

from .messaging.messaging import Messaging

from .catalog_items.catalog_items import CatalogItems, CatalogItemsVersion

from .product_type_definitions.product_type_definitions import ProductTypeDefinitions

from .listings_items.listings_items import ListingsItems

from .vendor_transaction_status.vendor_transaction_status import VendorTransactionStatus

from .vendor_shipments.vendor_shipments import VendorShipments

from .vendor_orders.vendor_orders import VendorOrders

from .vendor_invoices.vendor_invoices import VendorInvoices

from .vendor_direct_fulfillment_transactions.vendor_direct_fulfillment_transactions import \
    VendorDirectFulfillmentTransactions

from .vendor_direct_fulfillment_shipping.vendor_direct_fulfillment_shipping import VendorDirectFulfillmentShipping

from .vendor_direct_fulfillment_payments.vendor_direct_fulfillment_payments import VendorDirectFulfillmentPayments

from .vendor_direct_fulfillment_orders.vendor_direct_fulfillment_orders import VendorDirectFulfillmentOrders

from .vendor_direct_fulfillment_inventory.vendor_direct_fulfillment_inventory import VendorDirectFulfillmentInventory

from .tokens.tokens import Tokens

from .solicitations.solicitations import Solicitations

from .shipping.shipping import Shipping

from .services.services import Services

from .fba_small_and_light.fba_small_and_light import FbaSmallAndLight

from .fba_inbound_eligibility.fba_inbound_eligibility import FbaInboundEligibility

from .authorization.authorization import Authorization

from .aplus_content.aplus_content import AplusContent

from .fulfillment_outbound.fulfillment_outbound import FulfillmentOutbound

from .replenishment.replenishment import Replenishment

from .supply_sources.supply_sources import SupplySources

from .data_kiosk.data_kiosk import DataKiosk

from .application_management.application_management import ApplicationManagement

__all__ = [
    "Sales",
    "Products",
    "Reports",
    "Orders",
    "Sellers",
    "Notifications",
    "ProductFees",
    "Finances",
    "Catalog",
    "Feeds",
    "Inventories",
    "FulfillmentInbound",
    'Upload',
    "Messaging",
    "FulfillmentInbound",
    "MerchantFulfillment",
    ##### DO NOT DELETE ########## INSERT TITLE HERE #######
    "ListingsRestrictions",
    "CatalogItemsVersion",
    "Feeds",
    "FeedsV2",
    "ReportsV2",

    "Messaging",

    "CatalogItems",

    "ProductTypeDefinitions",

    "ListingsItems",

    "VendorTransactionStatus",

    "VendorShipments",

    "VendorOrders",

    "VendorInvoices",

    "VendorDirectFulfillmentTransactions",

    "VendorDirectFulfillmentShipping",

    "VendorDirectFulfillmentPayments",

    "VendorDirectFulfillmentOrders",

    "VendorDirectFulfillmentInventory",

    "Tokens",

    "Solicitations",

    "Shipping",

    "Services",

    "FbaSmallAndLight",

    "FbaInboundEligibility",

    "Authorization",

    "AplusContent",

    "FulfillmentOutbound",

    "Replenishment",

    "SupplySources",

    "DataKiosk",

    "ApplicationManagement"

]
